import { resolve } from 'path';
import * as builtinModules from 'builtin-modules';

function externals(options = {}) {
    const warnings = [];
    const opts = Object.assign({ packagePath: resolve(process.cwd(), 'package.json'), builtins: true, deps: false, devDeps: true, peerDeps: true, optDeps: true, include: [], exclude: [], except: [] }, options);
    const [include, exclude, except] = ['include', 'exclude', 'except'].map(option => new Array()
        .concat(opts[option])
        .map((entry, index) => {
        if (entry instanceof RegExp) {
            return entry;
        }
        else if (typeof entry === 'string') {
            return new RegExp('^' + entry.replace(/[.*+?^${}()|[\]\\]/g, '\\$&') + '$');
        }
        else {
            warnings.push(`Ignoring wrong entry type #${index} in '${option}' option: '${entry}'`);
            return /(?=no)match/;
        }
    }));
    if (except.length > 0) {
        warnings.push("'except' option is deprecated, please use include/exclude instead");
        exclude.push(...except);
    }
    const f = dep => !exclude.some(rx => rx.test(dep));
    const builtins = (opts.builtins ? builtinModules : []).filter(f);
    let pkg;
    try {
        pkg = require(opts.packagePath);
    }
    catch (_a) {
        warnings.push("couldn't read package.json, please make sure it exists in the same directory as rollup.config.js or use the 'packagePath' option.");
        pkg = Object.create(null);
    }
    const dependencies = [
        ...(opts.deps ? Object.keys(pkg.dependencies || {}) : []),
        ...(opts.devDeps ? Object.keys(pkg.devDependencies || {}) : []),
        ...(opts.peerDeps ? Object.keys(pkg.peerDependencies || {}) : []),
        ...(opts.optDeps ? Object.keys(pkg.optionalDependencies || {}) : [])
    ].filter(f);
    const externals = [];
    if (builtins.length > 0) {
        externals.push(new RegExp('^(?:' + builtins.join('|') + ')(\/.+)?$'));
    }
    if (dependencies.length > 0) {
        externals.push(new RegExp('^(?:' + dependencies.join('|') + ')(\/.+)?$'));
    }
    if (include.length > 0) {
        externals.push(...include);
    }
    return {
        name: 'node-externals',
        resolveId(importee, importer) {
            return importer && !/\0/.test(importee) && externals.some(deps => deps.test(importee)) ? false : null;
        },
        buildStart() {
            let msg;
            while (msg = warnings.shift()) {
                this.warn(msg);
            }
        }
    };
}

export default externals;
//# sourceMappingURL=index.js.map
