"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const typescript_1 = __importDefault(require("typescript"));
const deriveUniqueName_1 = __importDefault(require("./deriveUniqueName"));
function transformer(program) {
    const visitor = (node) => visitNode(node, program);
    return (context) => (source) => typescript_1.default.visitEachChild(source, visitor, context);
}
exports.default = transformer;
function visitNode(node, program) {
    if (typescript_1.default.isExportAssignment(node) && !node.isExportEquals && typescript_1.default.isArrowFunction(node.expression)) {
        return nameExportedArrowFunction(node, deriveUniqueName_1.default(node, program));
    }
    if (typescript_1.default.isFunctionDeclaration(node) && !node.name && isExportDefault(node)) {
        return updateFunctionDeclarationName(node, deriveUniqueName_1.default(node, program));
    }
    if (typescript_1.default.isClassDeclaration(node) && !node.name && isExportDefault(node)) {
        return updateClassDeclarationName(node, deriveUniqueName_1.default(node, program, true));
    }
    return node;
}
function isExportDefault(node) {
    const modifier = typescript_1.default.ModifierFlags.ExportDefault;
    return (typescript_1.default.getCombinedModifierFlags(node) & modifier) === modifier;
}
function nameExportedArrowFunction(node, name) {
    return [
        createConstVariableStatement(name, undefined, node.expression),
        typescript_1.default.updateExportAssignment(node, node.decorators, node.modifiers, name),
    ];
}
function createConstVariableStatement(...args) {
    return typescript_1.default.createVariableStatement(undefined, typescript_1.default.createVariableDeclarationList([typescript_1.default.createVariableDeclaration(...args)], typescript_1.default.NodeFlags.Const));
}
function updateClassDeclarationName(node, name) {
    return typescript_1.default.updateClassDeclaration(node, node.decorators, node.modifiers, name, node.typeParameters, node.heritageClauses, node.members);
}
function updateFunctionDeclarationName(node, name) {
    return typescript_1.default.updateFunctionDeclaration(node, node.decorators, node.modifiers, node.asteriskToken, name, node.typeParameters, node.parameters, node.type, node.body);
}
//# sourceMappingURL=index.js.map